//+------------------------------------------------------------------+
//|                                         ClassPriceAdjustment.mqh |
//|                                            Rafael Floriani Pinto |
//|                           https://www.mql5.com/pt/users/rafaelfp |
//+------------------------------------------------------------------+
#property copyright "Rafael Floriani Pinto"
#property link      "https://www.mql5.com/pt/users/rafaelfp"
//+------------------------------------------------------------------+
//| defines                                                          |
//+------------------------------------------------------------------+
#ifndef ClassPriceAdjustmentV1rafaelfp
#define ClassPriceAdjustmentV1rafaelfp
//+------------------------------------------------------------------+
//| PROTOTYPE                                                        |
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
class CPriceAdjustmentV1
  {
public:
   //CONSTRUCTOR
                     CPriceAdjustmentV1(const string=NULL);
   //DESTROYER
                    ~CPriceAdjustmentV1();
   //
   string            GetSymbolName()const;
   void              PrintSymbolInfo()const;
   double            AdjustPrice(double)const;
   double            PointsToPriceTPBuy(int,double)const;
   double            PointsToPriceSLBuy(int,double)const;
   double            PointsToPriceTPSell(int,double)const;
   double            PointsToPriceSLSell(int,double)const;

private:
   string            SNameVerify(const string);
   int               GetPot();
   const string      Symbol_Name;
   const int         S_Digits;
   const double      S_TickSize;
   const int         S_Pot;
   const int         S_TickSizeInt;


  };
//+------------------------------------------------------------------+
//| DEFINITIONS                                                      |
//+------------------------------------------------------------------+

//CONSTRUCTOR
CPriceAdjustmentV1::CPriceAdjustmentV1(const string SSymbol)
   :Symbol_Name(SNameVerify(SSymbol)),
    S_Digits((int)SymbolInfoInteger(Symbol_Name,SYMBOL_DIGITS)),
    S_TickSize((double)SymbolInfoDouble(Symbol_Name,SYMBOL_TRADE_TICK_SIZE)),
    S_Pot(GetPot()),
    S_TickSizeInt((int)(S_TickSize*S_Pot))
  {

  }
//DESTROYER
CPriceAdjustmentV1::~CPriceAdjustmentV1()
  {

  }
//+------------------------------------------------------------------+
//| PUBLIC DEFINITIONS                                               |
//+------------------------------------------------------------------+
string CPriceAdjustmentV1::GetSymbolName(void)const
  {
   return Symbol_Name;
  }


//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void CPriceAdjustmentV1::PrintSymbolInfo(void)const
  {
   printf("Symbol name is %s",Symbol_Name);
   printf("Symbol digits is %d",S_Digits);
   printf("Symbol ticksize is %f",S_TickSize);
   printf("Symbol Pot %f",S_Pot);
   printf("Symbol ticksizeint is %f",S_TickSizeInt);
  }


//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CPriceAdjustmentV1::AdjustPrice(double Price)const
  {
   double PriceD=(NormalizeDouble(Price,S_Digits)*S_Pot);
   int PriceI=(int)PriceD;
   if(PriceI%S_TickSizeInt<=(S_TickSizeInt/2))
     {
      PriceI-=(PriceI%S_TickSizeInt);
     }
   else
      PriceI+=(S_TickSizeInt-PriceI%S_TickSizeInt);
   PriceD=PriceI;
   PriceD/=S_Pot;
   return PriceD;
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CPriceAdjustmentV1::PointsToPriceTPBuy(int Points,double Price)const
  {
   double Val=(double)(Points*S_TickSize);
   return AdjustPrice(Price+Val);
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CPriceAdjustmentV1::PointsToPriceSLBuy(int Points,double Price)const
  {
   double Val=(double)(Points*S_TickSize);
   return AdjustPrice(Price-Val);
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CPriceAdjustmentV1::PointsToPriceTPSell(int Points,double Price)const
  {
   double Val=(double)(Points*S_TickSize);
   return AdjustPrice(Price-Val);
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CPriceAdjustmentV1::PointsToPriceSLSell(int Points,double Price)const
  {
   double Val=(double)(Points*S_TickSize);
   return AdjustPrice(Price+Val);
  }





//+------------------------------------------------------------------+
//| PRIVATE DEFINITIONS                                              |
//+------------------------------------------------------------------+
//NAME VERIFY
string CPriceAdjustmentV1::SNameVerify(const string SName)
  {
   if(SName==NULL)
      return _Symbol;
   if(SymbolInfoInteger(SName,SYMBOL_EXIST))
      return SName;
   return _Symbol;
  }


//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int CPriceAdjustmentV1::GetPot(void)
  {
   int Pot=1;
   for(int i=0; i<S_Digits; i++)
      Pot*=10;
   return Pot;
  }





//+------------------------------------------------------------------+
//| END                                                              |
//+------------------------------------------------------------------+


#endif
//+------------------------------------------------------------------+
